summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kreportsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kreportsview.h')
-rwxr-xr-xkmymoney2/views/kreportsview.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmymoney2/views/kreportsview.h b/kmymoney2/views/kreportsview.h
index 218155a..493b312 100755
--- a/kmymoney2/views/kreportsview.h
+++ b/kmymoney2/views/kreportsview.h
@@ -102,7 +102,7 @@ public:
reports::ReportTable* m_table;
public:
- KReportTab(KTabWidget* tqparent, const MyMoneyReport& report );
+ KReportTab(KTabWidget* parent, const MyMoneyReport& report );
~KReportTab();
const MyMoneyReport& report(void) const { return m_report; }
void print(void);
@@ -134,13 +134,13 @@ public:
MyMoneyReport m_report;
public:
- KReportListItem( KListView* tqparent, const MyMoneyReport& report ):
- KListViewItem( tqparent, report.name(), report.comment() ),
+ KReportListItem( KListView* parent, const MyMoneyReport& report ):
+ KListViewItem( parent, report.name(), report.comment() ),
m_id( report.id() ),
m_report( report )
{}
- KReportListItem( KListViewItem* tqparent, const MyMoneyReport& report ):
- KListViewItem( tqparent, report.name(), report.comment() ),
+ KReportListItem( KListViewItem* parent, const MyMoneyReport& report ):
+ KListViewItem( parent, report.name(), report.comment() ),
m_id( report.id() ),
m_report( report )
{}
@@ -155,7 +155,7 @@ public:
TQString m_name;
public:
- KReportGroupListItem( KListView* tqparent,const int nr,const TQString name);
+ KReportGroupListItem( KListView* parent,const int nr,const TQString name);
virtual TQString key ( int column, bool ascending ) const;
void setNr(const int nr);
};
@@ -195,14 +195,14 @@ public:
/**
* Standard constructor.
*
* @param tqparent The TQWidget this is used in.
* @param name The QT name.
*
* @return An object of type KReportsView
*
* @see ~KReportsView
*/
- KReportsView(TQWidget *tqparent=0, const char *name=0);
+ KReportsView(TQWidget *parent=0, const char *name=0);
/**
* Standard destructor.
@@ -195,14 +195,14 @@ public:
* Standard constructor.
*
- * @param tqparent The TQWidget this is used in.
+ * @param parent The TQWidget this is used in.
* @param name The QT name.
*